Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(239)

Unified Diff: src/runtime/runtime-scopes.cc

Issue 1664683002: Expect JSReceiver in Runtime_DeleteLookupSlot, not just JSObject. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Blacklist regression test for ignition (no with support) Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | test/mjsunit/mjsunit.status » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/runtime/runtime-scopes.cc
diff --git a/src/runtime/runtime-scopes.cc b/src/runtime/runtime-scopes.cc
index 265ce83c6eb767c6148c2d351e44f4f65e904917..c5890e7071795daf7788577b899410f8b26584bf 100644
--- a/src/runtime/runtime-scopes.cc
+++ b/src/runtime/runtime-scopes.cc
@@ -979,10 +979,10 @@ RUNTIME_FUNCTION(Runtime_DeleteLookupSlot) {
return isolate->heap()->false_value();
}
// The slot was found in a JSObject, either a context extension object,
// the global object, or the subject of a with. Try to delete it
// (respecting DONT_DELETE).
- Handle<JSObject> object = Handle<JSObject>::cast(holder);
+ Handle<JSReceiver> object = Handle<JSReceiver>::cast(holder);
Maybe<bool> result = JSReceiver::DeleteProperty(object, name);
MAYBE_RETURN(result, isolate->heap()->exception());
return isolate->heap()->ToBoolean(result.FromJust());
@@ -979,10 +979,10 @@ RUNTIME_FUNCTION(Runtime_DeleteLookupSlot) {
return isolate->heap()->false_value();
}
- // The slot was found in a JSObject, either a context extension object,
+ // The slot was found in a JSReceiver, either a context extension object,
// the global object, or the subject of a with. Try to delete it
// (respecting DONT_DELETE).
« no previous file with comments | « no previous file | test/mjsunit/mjsunit.status » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698